AndroidConfig

Struct AndroidConfig 

pub struct AndroidConfig {
    pub bandwidth_constrained_ok: Option<bool>,
    pub collapse_key: Option<String>,
    pub data: Option<HashMap<String, String>>,
    pub direct_boot_ok: Option<bool>,
    pub fcm_options: Option<AndroidFcmOptions>,
    pub notification: Option<AndroidNotification>,
    pub priority: Option<String>,
    pub restricted_package_name: Option<String>,
    pub restricted_satellite_ok: Option<bool>,
    pub ttl: Option<Duration>,
}
Android specific options for messages sent through FCM connection server.

This type is not used in any activity, and only used as part of another schema.

Fields

bandwidth_constrained_ok: Option<bool>

Optional. If set to true, messages will be allowed to be delivered to the app while the device is in bandwidth constrained mode. This should only be enabled when the app has been tested to properly handle messages in bandwidth constrained mode.

collapse_key: Option<String>

An identifier of a group of messages that can be collapsed, so that only the last message gets sent when delivery can be resumed. A maximum of 4 different collapse keys is allowed at any given time.

data: Option<HashMap<String, String>>

Arbitrary key/value payload. If present, it will override google.firebase.fcm.v1.Message.data.

direct_boot_ok: Option<bool>

Optional. If set to true, messages will be allowed to be delivered to the app while the device is in direct boot mode. See Support Direct Boot mode.

fcm_options: Option<AndroidFcmOptions>

Options for features provided by the FCM SDK for Android.

notification: Option<AndroidNotification>

Notification to send to android devices.

priority: Option<String>

Message priority. Can take “normal” and “high” values. For more information, see Setting the priority of a message.

restricted_package_name: Option<String>

Package name of the application where the registration token must match in order to receive the message.

restricted_satellite_ok: Option<bool>

Optional. If set to true, messages will be allowed to be delivered to the app while the device is connected over a restricted satellite network. This should only be enabled for messages that can be handled over a restricted satellite network and only for apps that are enabled to work over a restricted satellite network. Note that the ability of the app to connect to a restricted satellite network is dependent on the carrier’s settings and the device model.

ttl: Option<Duration>

How long (in seconds) the message should be kept in FCM storage if the device is offline. The maximum time to live supported is 4 weeks, and the default value is 4 weeks if not set. Set it to 0 if want to send the message immediately. In JSON format, the Duration type is encoded as a string rather than an object, where the string ends in the suffix “s” (indicating seconds) and is preceded by the number of seconds, with nanoseconds expressed as fractional seconds. For example, 3 seconds with 0 nanoseconds should be encoded in JSON format as “3s”, while 3 seconds and 1 nanosecond should be expressed in JSON format as “3.000000001s”. The ttl will be rounded down to the nearest second.