pub struct ApnsFcmOptions {
pub analytics_label: Option<String>,
pub image: Option<String>,
}Expand description
Options for features provided by the FCM SDK for iOS.
This type is not used in any activity, and only used as part of another schema.
Fields
analytics_label: Option<String>Label associated with the message’s analytics data.
image: Option<String>Contains the URL of an image that is going to be displayed in a notification. If present, it will override google.firebase.fcm.v1.Notification.image.