pub struct FcmOptions {
pub analytics_label: Option<String>,
}Expand description
Platform independent options for features provided by the FCM SDKs.
This type is not used in any activity, and only used as part of another schema.
Fields
analytics_label: Option<String>Label associated with the message’s analytics data.