pub struct ProjectMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on project resources.
It is not used directly, but through the FirebaseCloudMessaging hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_fcm1 as fcm1;
use fcm1::{FirebaseCloudMessaging, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = FirebaseCloudMessaging::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `messages_send(...)`
// to build up your call.
let rb = hub.projects();Implementations
Sourceimpl<'a, C> ProjectMethods<'a, C>
impl<'a, C> ProjectMethods<'a, C>
Sourcepub fn messages_send(
&self,
request: SendMessageRequest,
parent: &str,
) -> ProjectMessageSendCall<'a, C>
pub fn messages_send( &self, request: SendMessageRequest, parent: &str, ) -> ProjectMessageSendCall<'a, C>
Create a builder to help you perform the following task:
Send a message to specified target (a registration token, topic or condition).
Arguments
request- No description provided.parent- Required. It contains the Firebase project id (i.e. the unique identifier for your Firebase project), in the format ofprojects/{project_id}. The numeric project number with no padding is also supported in the format ofprojects/{project_number}.