pub struct WebpushConfig {
pub data: Option<HashMap<String, String>>,
pub fcm_options: Option<WebpushFcmOptions>,
pub headers: Option<HashMap<String, String>>,
pub notification: Option<HashMap<String, Value>>,
}Expand description
Webpush protocol options.
This type is not used in any activity, and only used as part of another schema.
Fields
data: Option<HashMap<String, String>>Arbitrary key/value payload. If present, it will override google.firebase.fcm.v1.Message.data.
fcm_options: Option<WebpushFcmOptions>Options for features provided by the FCM SDK for Web.
headers: Option<HashMap<String, String>>HTTP headers defined in webpush protocol. Refer to Webpush protocol for supported headers, e.g. “TTL”: “15”.
notification: Option<HashMap<String, Value>>Web Notification options as a JSON object. Supports Notification instance properties as defined in Web Notification API. If present, “title” and “body” fields override [google.firebase.fcm.v1.Notification.title] and [google.firebase.fcm.v1.Notification.body].