pub struct ApnsConfig {
pub fcm_options: Option<ApnsFcmOptions>,
pub headers: Option<HashMap<String, String>>,
pub live_activity_token: Option<String>,
pub payload: Option<HashMap<String, Value>>,
}Expand description
Apple Push Notification Service specific options.
This type is not used in any activity, and only used as part of another schema.
Fields
fcm_options: Option<ApnsFcmOptions>Options for features provided by the FCM SDK for iOS.
headers: Option<HashMap<String, String>>HTTP request headers defined in Apple Push Notification Service. Refer to APNs request headers for supported headers such as apns-expiration and apns-priority. The backend sets a default value for apns-expiration of 30 days and a default value for apns-priority of 10 if not explicitly set.
live_activity_token: Option<String>Optional. Apple Live Activity token to send updates to. This token can either be a push token or push-to-start token from Apple. To start, update, or end a live activity remotely using FCM, construct an aps payload and put it in the apns.payload field.
payload: Option<HashMap<String, Value>>APNs payload as a JSON object, including both aps dictionary and custom payload. See Payload Key Reference. If present, it overrides google.firebase.fcm.v1.Notification.title and google.firebase.fcm.v1.Notification.body.